@@ -279,7 +279,7 @@ class Loaf:
                 values = ", ".join(values)
         # Execute the query.
         try:
-            self.cursor.execute(f"INSERT INTO table ({into}) VALUES ({values})")
+            self.cursor.execute(f"INSERT INTO {table} ({into}) VALUES ({values})")
         except Exception as e:
             if rollback_on_error:
                 self.conn.rollback()
